@@ -54,6 +54,13 @@ TASK_STATE_CHOICES = sorted(zip(ALL_STATES, ALL_STATES))
 
 
 # Create your models here.
+class TaskDashboard(models.Model):
+    class Meta:
+        verbose_name = u'任务监控'
+        verbose_name_plural = verbose_name
+        db_table = "tasks_dashboard"
+
+
 class Task(models.Model):
     name = models.CharField(
         primary_key=True, max_length=50, verbose_name=u'NAME',
@@ -695,17 +702,6 @@ class TaskResult(models.Model):
         return '<Task: {0.task_id} ({0.status})>'.format(self)
 
 
-class TaskStartDatetime(models.Model):
-    task_id = models.CharField(
-        max_length=getattr(settings, 'DJANGO_CELERY_RESULTS_TASK_ID_MAX_LENGTH', 255),
-        unique=True, db_index=True, verbose_name=u'Task ID')
-    date_start = models.DateTimeField(
-        auto_now_add=True, blank=True, null=True, verbose_name=u'Started DateTime')
-
-    class Meta:
-        db_table = "tasks_start_datetime"
-
-
 signals.pre_delete.connect(PeriodicTasks.changed, sender=PeriodicTask)
 signals.pre_save.connect(PeriodicTasks.changed, sender=PeriodicTask)
 signals.pre_delete.connect(
