@@ -16,14 +16,9 @@ Including another URLconf
 
 from django.urls import path
 
-from django_opstasks.views import (
-    error_test, args_test, longtime_test,
-    sync_task_to_database
-)
+from django_opstasks.views import error_test, sync_task_to_database
 
 urlpatterns = [
     path('error', error_test),
-    path('add', args_test),
-    path('longtime', longtime_test),
     path('database', sync_task_to_database),
 ]
